"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const util_1 = __importDefault(require("aws-sdk/lib/util"));
const configOptInEnv = 'AWS_SDK_LOAD_CONFIG';
const sharedConfigFileEnv = 'AWS_CONFIG_FILE';
const sharedCredentialsFileEnv = 'AWS_SHARED_CREDENTIALS_FILE';
function isSsoProfileConfig(c) {
    if (c === undefined || c === null)
        return false;
    if (typeof c !== 'object')
        return false;
    if (!('sso_account_id' in c
        && 'sso_region' in c
        && 'sso_role_name' in c
        && 'sso_start_url' in c))
        return false;
    if (typeof c.sso_account_id !== 'string')
        return false;
    if (typeof c.sso_region !== 'string')
        return false;
    if (typeof c.sso_role_name !== 'string')
        return false;
    if (typeof c.sso_start_url !== 'string')
        return false;
    return true;
}
const getProfilesFromCredentialsFile = (iniLoader) => {
    const filename = process.env[configOptInEnv];
    const config = iniLoader.loadFrom({
        isConfig: true,
        filename,
    });
    return {
        config,
        keys: Object.keys(config),
        values: Object.values(config),
    };
};
const getProfilesFromConfigFile = (iniLoader, filename) => {
    const configFilename = filename
        || (process.env[configOptInEnv] && process.env[sharedCredentialsFileEnv]);
    const config = iniLoader.loadFrom({
        filename: configFilename,
    });
    return {
        config,
        keys: Object.keys(config),
        values: Object.values(config),
    };
};
const fillProfilesFromConfiguration = (configuration, profiles) => {
    const { values, keys } = configuration;
    const newProfiles = profiles;
    if (values && keys) {
        keys.forEach((profileName, index) => {
            const foundProfile = values[index];
            newProfiles[profileName] = {
                ...profiles[profileName],
                ...foundProfile,
            };
        });
    }
    return newProfiles;
};
const getSsoSessions = (iniLoader, filename) => {
    const filenameForSessions = filename
        || (process.env[sharedConfigFileEnv] && process.env[sharedCredentialsFileEnv]);
    const config = iniLoader.loadSsoSessionsFrom({
        filename: filenameForSessions,
    });
    return {
        config,
        keys: Object.keys(config),
        values: Object.values(config),
    };
};
const addSsoDataToProfiles = (sessionConfiguration, profiles) => {
    const profileNames = Object.keys(profiles);
    const profilesWithSessionData = profiles;
    profileNames.forEach((profileName) => {
        sessionConfiguration.keys.forEach((ssoSessionName) => {
            if (ssoSessionName === profiles[profileName].sso_session) {
                const session = sessionConfiguration.config[ssoSessionName];
                profilesWithSessionData[profileName] = {
                    ...profiles[profileName],
                    sso_start_url: session.sso_start_url,
                };
            }
        });
    });
    return profilesWithSessionData;
};
const getProfilesFromSsoConfig = (iniLoader, filename) => {
    const configurations = {
        profilesFromConfig: getProfilesFromCredentialsFile(iniLoader),
        profilesFromCredentials: getProfilesFromConfigFile(iniLoader, filename),
        ssoSessions: getSsoSessions(iniLoader, filename),
    };
    const profilesFromConfig = fillProfilesFromConfiguration(configurations.profilesFromConfig, {});
    const allProfiles = fillProfilesFromConfiguration(configurations.profilesFromCredentials, profilesFromConfig);
    const profilesWithSsoData = addSsoDataToProfiles(configurations.ssoSessions, allProfiles);
    return profilesWithSsoData;
};
function getSsoConfig(options) {
    if (!options.profile) {
        throw new Error('Cannot load SSO credentials without a profile');
    }
    const profiles = getProfilesFromSsoConfig(
    // https://github.com/aws/aws-sdk-js/pull/4456
    util_1.default.iniLoader, options.filename);
    const config = profiles[options.profile];
    if (!isSsoProfileConfig(config)) {
        throw new Error(`Profile ${options.profile} does not have valid SSO credentials. Required `
            + 'parameters "sso_account_id", "sso_region", "sso_role_name", '
            + '"sso_start_url". Reference: '
            + 'https://docs.aws.amazon.com/cli/latest/userguide/cli-configure-sso.html');
    }
    return config;
}
exports.default = getSsoConfig;
//# sourceMappingURL=getSsoConfig.js.map